"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Setting_1 = require("@joplin/lib/models/Setting");
const RepositoryApi_1 = require("@joplin/lib/services/plugins/RepositoryApi");
const shim_1 = require("@joplin/lib/shim");
const test_utils_1 = require("@joplin/lib/testing/test-utils");
const fs_extra_1 = require("fs-extra");
let tempDirs = [];
async function newRepoApi(appInfo = { type: Setting_1.AppType.Desktop, version: '3.0.0' }) {
    const tempDir = await (0, test_utils_1.createTempDir)();
    tempDirs.push(tempDir);
    const repo = new RepositoryApi_1.default(`${test_utils_1.supportDir}/pluginRepo`, tempDir, appInfo, RepositoryApi_1.InstallMode.Default);
    await repo.initialize();
    return repo;
}
describe('services_plugins_RepositoryApi', () => {
    beforeEach(async () => {
        await (0, test_utils_1.setupDatabaseAndSynchronizer)(1);
        await (0, test_utils_1.switchClient)(1);
    });
    afterEach(async () => {
        for (const tempDir of tempDirs) {
            await (0, fs_extra_1.remove)(tempDir);
        }
        tempDirs = [];
    });
    it('should get the manifests', (async () => {
        const api = await newRepoApi();
        const manifests = await api.manifests();
        expect(!!manifests.find(m => m.id === 'joplin.plugin.ambrt.backlinksToNote')).toBe(true);
        expect(!!manifests.find(m => m.id === 'org.joplinapp.plugins.ToggleSidebars')).toBe(true);
    }));
    it('should search', (async () => {
        const api = await newRepoApi();
        {
            const results = await api.search('to');
            expect(results.length).toBe(3);
            expect(!!results.find(m => m.id === 'joplin.plugin.ambrt.backlinksToNote')).toBe(true);
            expect(!!results.find(m => m.id === 'org.joplinapp.plugins.ToggleSidebars')).toBe(true);
            expect(!!results.find(m => m.id === 'org.joplinapp.plugins.AbcSheetMusic')).toBe(true);
        }
        {
            const results = await api.search('backlink');
            expect(results.length).toBe(1);
            expect(!!results.find(m => m.id === 'joplin.plugin.ambrt.backlinksToNote')).toBe(true);
        }
    }));
    it('should download a plugin', (async () => {
        const api = await newRepoApi();
        const pluginPath = await api.downloadPlugin('org.joplinapp.plugins.ToggleSidebars');
        expect(await shim_1.default.fsDriver().exists(pluginPath)).toBe(true);
    }));
    it.each([
        { id: 'org.joplinapp.plugins.ToggleSidebars', installedVersion: '1.0.0', appVersion: '3.0.0', shouldBeUpdatable: true },
        { id: 'org.joplinapp.plugins.ToggleSidebars', installedVersion: '1.0.0', appVersion: '1.0.0', shouldBeUpdatable: false },
        { id: 'org.joplinapp.plugins.ToggleSidebars', installedVersion: '1.0.2', appVersion: '3.0.0', shouldBeUpdatable: false },
        { id: 'does.not.exist', installedVersion: '1.0.0', appVersion: '3.0.0', shouldBeUpdatable: false },
    ])('should tell if a plugin can be updated (case %#)', (async ({ id, installedVersion, appVersion, shouldBeUpdatable }) => {
        const api = await newRepoApi({ version: appVersion, type: Setting_1.AppType.Desktop });
        expect(await api.pluginCanBeUpdated(id, installedVersion)).toBe(shouldBeUpdatable);
    }));
});
//# sourceMappingURL=RepositoryApi.js.map