"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const KeymapService_1 = require("@joplin/lib/services/KeymapService");
const test_utils_1 = require("@joplin/lib/testing/test-utils");
const testUtils_1 = require("../../../testUtils");
describe('JoplinViewMenuItem', () => {
    beforeEach(async () => {
        await (0, test_utils_1.setupDatabaseAndSynchronizer)(1);
        await (0, test_utils_1.switchClient)(1);
    });
    afterEach(async () => {
        await (0, test_utils_1.afterEachCleanUp)();
    });
    test('should register commands with the keymap service', async () => {
        const service = (0, testUtils_1.newPluginService)();
        KeymapService_1.default.instance().initialize();
        const pluginScript = (0, testUtils_1.newPluginScript)(`			
			joplin.plugins.register({
				onStart: async function() {
					await joplin.commands.register({
						name: 'testCommand1',
						label: 'My Test Command 1',
						iconName: 'fas fa-music',
						execute: async () => {},
					});

					await joplin.views.menuItems.create('myMenuItem1', 'testCommand1', 'tools', { accelerator: 'CmdOrCtrl+Alt+Shift+B' });

					await joplin.commands.register({
						name: 'testCommand2',
						label: 'My Test Command 2',
						iconName: 'fas fa-music',
						execute: async () => {},
					});

					await joplin.views.menuItems.create('myMenuItem2', 'testCommand2', 'tools');
				},
			});
		`);
        const plugin = await service.loadPluginFromJsBundle('', pluginScript);
        await service.runPlugin(plugin);
        const commandNames = KeymapService_1.default.instance().getCommandNames();
        expect(commandNames.includes('testCommand1')).toBe(true);
        expect(commandNames.includes('testCommand2')).toBe(true);
        await service.destroy();
    });
});
//# sourceMappingURL=JoplinViewMenuItem.js.map